package orderservicelogic

import (
	"app-cloudep-order-server/gen_result/pb/order"
	mockmodel "app-cloudep-order-server/internal/mock/model"
	"app-cloudep-order-server/internal/svc"
	"context"
	"errors"
	"testing"

	"github.com/stretchr/testify/assert"
	"go.uber.org/mock/gomock"
)

func TestOrderStatusTimeout(t *testing.T) {
	ctrl := gomock.NewController(t)
	defer ctrl.Finish()

	// 初始化 mock 依賴
	mockOrderModel := mockmodel.NewMockOrderModel(ctrl)

	// 初始化服務上下文
	svcCtx := &svc.ServiceContext{
		OrderModel: mockOrderModel,
	}

	// 測試數據集
	tests := []struct {
		name        string
		prepare     func()
		expectErr   bool
		expectedRes *order.OKResp
	}{
		{
			name: "成功更新訂單狀態",
			prepare: func() {
				// 模擬訂單狀態超時更新成功
				mockOrderModel.EXPECT().UpdateTimeoutOrder(gomock.Any(), gomock.Any()).Return(nil, nil).Times(1)
			},
			expectErr:   false,
			expectedRes: &order.OKResp{},
		},
		{
			name: "更新訂單狀態失敗",
			prepare: func() {
				// 模擬訂單狀態超時更新失敗
				mockOrderModel.EXPECT().UpdateTimeoutOrder(gomock.Any(), gomock.Any()).Return(nil, errors.New("update failed")).Times(1)
			},
			expectErr: true,
		},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			// 準備測試環境
			tt.prepare()

			// 初始化 OrderStatusTimeoutLogic
			logic := NewOrderStatusTimeoutLogic(context.TODO(), svcCtx)

			// 執行 OrderStatusTimeout
			resp, err := logic.OrderStatusTimeout(&order.OrderStatusTimeoutReq{})

			// 驗證結果
			if tt.expectErr {
				assert.Error(t, err)
				assert.Nil(t, resp)
			} else {
				assert.NoError(t, err)
				assert.Equal(t, tt.expectedRes, resp)
			}
		})
	}
}
