package model

import (
	"go.mongodb.org/mongo-driver/bson/primitive"
)

type Order struct {
	ID                   primitive.ObjectID    `bson:"_id,omitempty" json:"id,omitempty"`
	UpdateTime           int64                 `bson:"update_time"`
	CreateTime           int64                 `bson:"create_time"`
	BusinessID           string                `bson:"business_id"`                        // 訂單業務流水號
	OrderType            int8                  `bson:"order_type"`                         // 訂單類型
	OrderStatus          int8                  `bson:"order_status"`                       // 訂單狀態
	Brand                string                `bson:"brand"`                              // 下單平台
	OrderUID             string                `bson:"order_uid"`                          // 下單用戶 UID
	ReferenceID          string                `bson:"reference_id"`                       // 訂單來源
	Count                primitive.Decimal128  `bson:"count"`                              // 訂單數量
	OrderFee             primitive.Decimal128  `bson:"order_fee"`                          // 訂單手續費
	Amount               primitive.Decimal128  `bson:"amount"`                             // 單價
	ReferenceBrand       *string               `bson:"reference_brand,omitempty"`          // 訂單來源平台
	ReferenceUID         *string               `bson:"reference_uid,omitempty"`            // 訂單來源用戶 UID
	WalletStatus         *int64                `bson:"wallet_status,omitempty"`            // 交易金額狀態
	ThreePartyStatus     *int64                `bson:"three_party_status,omitempty"`       // 三方請求狀態
	DirectionType        *int64                `bson:"direction_type,omitempty"`           // 交易方向
	CryptoType           *string               `bson:"crypto_type,omitempty"`              // 交易幣種
	ThirdPartyFee        *primitive.Decimal128 `bson:"third_party_fee,omitempty"`          // 第三方手續費
	CryptoToUSDTRate     *primitive.Decimal128 `bson:"crypto_to_usdt_rate,omitempty"`      // 加密貨幣對 USDT 匯率
	FiatToUSDRate        *primitive.Decimal128 `bson:"fiat_to_usd_rate,omitempty"`         // 法幣對 USD 匯率
	FeeCryptoToUSDTRate  *primitive.Decimal128 `bson:"fee_crypto_to_usdt_rate,omitempty"`  // 手續費加密貨幣對 USDT 匯率
	USDTToCryptoTypeRate *primitive.Decimal128 `bson:"usdt_to_crypto_type_rate,omitempty"` // USDT 對加密貨幣匯率
	PaymentFiat          *string               `bson:"payment_fiat,omitempty"`             // 支付法幣
	PaymentUnitPrice     *primitive.Decimal128 `bson:"payment_unit_price,omitempty"`       // 加密貨幣單價
	PaymentTemplateID    *string               `bson:"payment_template_id,omitempty"`      // 支付方式配置 ID
	OrderArrivalTime     *int64                `bson:"order_arrival_time,omitempty"`       // 訂單到帳時間
	OrderPaymentTime     *int64                `bson:"order_payment_time,omitempty"`       // 訂單付款時間
	UnpaidTimeoutSecond  *int64                `bson:"unpaid_timeout_second,omitempty"`    // 支付期限秒數
	ChainType            *string               `bson:"chain_type,omitempty"`               // 主網類型
	TxHash               *string               `bson:"tx_hash,omitempty"`                  // 交易哈希
	FromAddress          *string               `bson:"from_address,omitempty"`             // 來源地址
	ToAddress            *string               `bson:"to_address,omitempty"`               // 目標地址
	ChainFee             *primitive.Decimal128 `bson:"chain_fee,omitempty"`                // 鏈上交易手續費
	ChainFeeCrypto       *string               `bson:"chain_fee_crypto,omitempty"`         // 鏈上手續費使用幣別
	Memo                 *string               `bson:"memo,omitempty"`                     // 鏈上備註
	OrderNote            *string               `bson:"order_note,omitempty"`               // 訂單交易備註
}

func (p *Order) CollectionName() string {
	return "order"
}
